@@ -157,9 +157,11 @@ gog_styled_object_class_init (GogObjectClass *gog_klass)
 	style_klass->init_style	    = gog_styled_object_init_style;
 
 	g_object_class_install_property (gobject_klass, STYLED_OBJECT_PROP_STYLE,
-		g_param_spec_object ("style", "style",
-			"GogStyle *",
-			GOG_STYLE_TYPE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_object ("style", 
+			_("Style"),
+			_("A pointer to the GogStyle object"),
+			GOG_STYLE_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 }
 
 static void
@@ -207,11 +209,11 @@ gog_styled_object_set_style (GogStyledObject *gso,
 }
 
 /**
- * gog_styled_object_get_style :
+ * gog_styled_object_get_style:
  * @gso: a #GogStyledObject
  *
  * Simply an accessor function that returns @gso->style, without referencing it.
- *
+ * 
  * return value: the styled object's #GogStyle
  **/
 GogStyle *
@@ -222,7 +224,7 @@ gog_styled_object_get_style (GogStyledObject *gso)
 }
 
 /**
- * gog_styled_object_get_auto_style :
+ * gog_styled_object_get_auto_style:
  * @gso: a #GogStyledObject
  *
  * This function returns a new style that is initialized with the auto values for @gso.
