@@ -76,6 +76,7 @@ go_regcomp (GORegexp *gor, const char *pat , int cflags)
   gor->ppcre = r = pcre_compile2 (pat, coptions,
 				  &errorcode, &errorptr, &errorofs,
 				  NULL);
+
   if (r == NULL) {
     switch (errorcode) {
     case 1: case 2: case 3: case 37: return REG_EESCAPE;
@@ -119,8 +120,7 @@ go_regexec (const GORegexp *gor, const char *txt,
       return REG_ESPACE;
 
     offsetcount = nmatch * 3;
-    /* FIXME: we really want g_try_new but that is recent.  */
-    offsets = allocated = g_new (int, offsetcount);
+    offsets = allocated = g_try_new (int, offsetcount);
     if (!offsets)
       return REG_ESPACE;
   } else {
@@ -269,11 +269,12 @@ go_search_replace_verify (GoSearchReplace *sr, gboolean repl, GError **err)
 	}
 
 	if (repl && !sr->replace_text) {
+		/* Probably a programmer error.  */
 		if (err)
 			g_set_error (err,
 				     go_search_replace_error_quark (),
 				     0,
-				     _("Search string must not be empty."));
+				     _("Replacement string must be set."));
 		return FALSE;
 	}
 
