@@ -129,14 +129,10 @@ gog_moving_avg_update (GogObject *obj)
 	double xtot = 0., ytot = 0.;
 	int nb, i, j, invalid;
 
-	if (ma->base.x != NULL) {
-		g_free (ma->base.x);
-		ma->base.x = NULL;
-	}
-	if (ma->base.y != NULL) {
-		g_free (ma->base.y);
-		ma->base.y = NULL;
-	}
+	g_free (ma->base.x);
+	ma->base.x = NULL;
+	g_free (ma->base.y);
+	ma->base.y = NULL;
 	if (!gog_series_is_valid (series))
 		return;
 
@@ -196,13 +192,17 @@ gog_moving_avg_class_init (GogSmoothedCurveClass *curve_klass)
 	gog_object_klass->type_name	= gog_moving_avg_type_name;
 
 	g_object_class_install_property (gobject_klass, MOVING_AVG_PROP_SPAN,
-		g_param_spec_int ("span", "span",
-			"Number of averaged values", 2, G_MAXINT, 3,
-			G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_int ("span", 
+			_("Span"),
+			_("Number of averaged values"), 
+			2, G_MAXINT, 3,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, MOVING_AVG_PROP_XAVG,
-		g_param_spec_boolean ("xavg", "xavg",
-			"Use averaged x values", TRUE,
-			G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("xavg", 
+			_("Average X"),
+			_("Use averaged x values"),
+		       	TRUE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 }
 
 static void
